
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.28.7',
    'branch_nick': 'release-1.28',
    'revision_id': 'c597bb65d2ab936b197916001b8012230f41d920',
    'revno': 11642
}
